namespace K3D.Geometry
{
   using System;
   using System.Diagnostics;


	/// <summary>
	/// ColourTriple.
	/// </summary>
	public sealed class ColourTriple
	{
      /// <summary>
      /// Constructor
      /// </summary>
		public ColourTriple(float r, float g, float b)
		{
         Red = r;
         Green = g;
         Blue = b;
		}

      /// <summary>
      /// Constructor
      /// </summary>
      /// <param name="r"></param>
      /// <param name="g"></param>
      /// <param name="b"></param>
      public ColourTriple(int r, int g, int b)
      {
         Red   = ((float)r)*RGB_BYTE_TO_FLOAT;
         Green = ((float)g)*RGB_BYTE_TO_FLOAT;
         Blue  = ((float)b)*RGB_BYTE_TO_FLOAT;
      }

      /// <summary>
      /// Constructor
      /// </summary>
      /// <param name="rgb"></param>
      public ColourTriple(int[] rgb)
      {
         if (rgb != null && rgb.Length == 3)
         {
            Red   = ((float)rgb[0])*RGB_BYTE_TO_FLOAT;
            Green = ((float)rgb[1])*RGB_BYTE_TO_FLOAT;
            Blue  = ((float)rgb[2])*RGB_BYTE_TO_FLOAT;
         }
      }

		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="color"></param>
		public ColourTriple(System.Drawing.Color color)
		{
			Red	= ((float)color.R)*RGB_BYTE_TO_FLOAT;
			Green = ((float)color.G)*RGB_BYTE_TO_FLOAT;
			Blue  = ((float)color.B)*RGB_BYTE_TO_FLOAT;
		}

      /// <summary>
      /// Convert the colour triple to an int array of 0-255 RGB values
      /// </summary>
      /// <returns>Int[] containing 3 RGB values</returns>
      public int[] ToRGB()
      {
         return new int[3] {(int)(Red/RGB_BYTE_TO_FLOAT),
                            (int)(Green/RGB_BYTE_TO_FLOAT),
                            (int)(Blue/RGB_BYTE_TO_FLOAT)};
      }

      /// <summary>
      /// Conver the colour triple to a System.Drawing.Color object
      /// </summary>
      /// <returns>System.Drawing.Color</returns>
      public System.Drawing.Color ToColor()
      {
         return System.Drawing.Color.FromArgb((int)(Red/RGB_BYTE_TO_FLOAT),
                                              (int)(Green/RGB_BYTE_TO_FLOAT),
                                              (int)(Blue/RGB_BYTE_TO_FLOAT));
      }

      /// <summary>
      /// Constant for RGB (byte) conversion to RGB (float)
      /// </summary>
      public const float RGB_BYTE_TO_FLOAT = 1.0f/255.0f;

      public float Red = 0.0f;
      public float Green = 0.0f;
      public float Blue = 0.0f;
	}
}
