namespace K3D.Geometry
{
	using System;
	using System.Collections;
	using System.Text;


	/// <summary>
	/// EdgeMap.
	/// Responsible for managing a map of vertex pairs to edges. This allows the
	/// subpatching algorithm to get/store the data it needs for its processing.
	/// </summary>
	public sealed class EdgeMap
	{
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="initialSize"></param>
		public EdgeMap(int initialSize)
		{
			m_map = new Hashtable(initialSize, 1.0f);
		}

		/// <summary>
		/// Indexer to retrieve an EdgeInfo structure
		/// </summary>
		public EdgeInfo this[int vertex1, int vertex2]
		{
			get
			{
				if (vertex1 > vertex2)
				{
					// swap to ensure consistency
					int temp = vertex1;
					vertex1 = vertex2;
					vertex2 = temp;
				}
				
				String key = vertex1.ToString() + '.' + vertex2.ToString();
				
				return (EdgeInfo)m_map[key];
			}
		}

		public int Count
		{
			get
			{
				return m_map.Count;
			}
		}

		/// <summary>
		/// Add an poly index for a specific edge (vertex to vertex)
		/// </summary>
		/// <param name="vertex1"></param>
		/// <param name="vertex2"></param>
		/// <param name="polyIndex"></param>
		public void AddPolyForEdge(int vertex1, int vertex2, int polyIndex)
		{
			if (vertex1 > vertex2)
			{
				// swap to ensure consistency
				int temp = vertex1;
				vertex1 = vertex2;
				vertex2 = temp;
			}
			
			String key = vertex1.ToString() + '.' + vertex2.ToString();
			
			if (m_map.Contains(key) == false)
			{
				EdgeInfo info = new EdgeInfo();
				info.PolygonIndex1 = polyIndex;
				m_map[key] = info;
			}
			else
			{
				((EdgeInfo)m_map[key]).PolygonIndex2 = polyIndex;
			}
		}


		/// <summary>
		/// Map of edge pair keys to polys (polys stored as shifted longs)
		/// </summary>
		private IDictionary m_map;
	}
}
