namespace K3D.Geometry
{
	using System;


	/// <summary>
	/// Point
	/// Represents a simple 3d point value
	/// </summary>
	public struct Point
	{
		// ------------------------------------------------------------------------------
		// Construction

		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="x">X coord</param>
		/// <param name="y">Y coord</param>
		/// <param name="z">Z coord</param>
		public Point(float x, float y, float z)
		{
			this.X = x;
			this.Y = y;
			this.Z = z;
		}

      /// <summary>
      /// Copy constructor
      /// </summary>
      /// <param name="p"></param>
      public Point(Point p)
      {
         this.X = p.X;
         this.Y = p.Y;
         this.Z = p.Z;
      }
      
      
		// ------------------------------------------------------------------------------
		// Public methods

      /// <summary>
      /// Copy values from a Point
      /// </summary>
      /// <param name="p"></param>
      public void CopyFrom(Point p)
      {
         this.X = p.X;
         this.Y = p.Y;
         this.Z = p.Z;
      }

		/// <summary>
		/// Equals override for a Point
		/// </summary>
		/// <param name="obj"></param>
		/// <returns></returns>
		public override bool Equals(object obj)
		{
			if (obj is Point)
			{
				Point p = (Point)obj;
				return (p.X == this.X && p.Y == this.Y && p.Z == this.Z);
			}
			else
			{
				return false;
			}
		}

		/// <summary>
		/// Return the Point in string format
		/// </summary>
		/// <returns>The Point as a string for output</returns>
		public override string ToString()
		{
			return "(" + this.X + "," + this.Y + "," + this.Z + ")";
		}
      
      
		// ------------------------------------------------------------------------------
		// Private data
      
		public float X;
		public float Y;
		public float Z;
	}
}
