namespace K3D.IO.IFF
{
	using System;

   using K3D.ThreeD;


	/// <summary>
	/// IChunkVisitor
	/// Visitor interface that deals with IFFChunk objects
	/// </summary>
	public interface IChunkVisitor
	{
		/// <summary>
		/// Deal with a single IFFChunk object.
		/// It is the responsibility of the vistor object to either Skip() the remainder
		/// of the chunk or GetData() as appropriate for this chunk type.
		/// </summary>
		/// <param name="chunk">An IFFChunk object</param>
		/// <param name="strId">The 4 character ID of the chunk</param>
		/// <param name="length">The length of the chunk in bytes</param>
		/// <returns>A ChunkReturn value as appropriate.</returns>
		ChunkReturn VisitChunk(IFFChunk chunk, string strId, int length);

		/// <summary>
		/// Inform the visitor that all chunks have been processed
		/// </summary>
		void EndVisit();

      /// <summary>
      /// Return the 3D object created by the visitor
      /// </summary>
      /// <returns>ThreeDObject or null if not created yet</returns>
      ThreeDObject Get3DObject();
	}
   
   
	/// <summary>
	/// ChunkReturn enum represents the return values from IChunkVisitor.VisitChunk
	/// </summary>
	public enum ChunkReturn
	{
		// visitor requests to skip (ignore) this chunk data
		Skip = 0,
		// visitor requests to read the next chunk in this chunk hierarchy
		ReadNextChunk = 1,
		// visitor requests to read the next sub-chunk in this chunk hierarchy
		ReadNextSubChunk = 2
	}
}
