namespace K3D.Properties
{
	using System;
	using System.Collections;
	using System.ComponentModel;
	using System.Drawing;
	using System.Data;
	using System.Windows.Forms;

	using K3D.Services;
	using K3D;


	/// <summary>
	/// Polygon Properties.
	/// </summary>
	public sealed class DetailProperties : System.Windows.Forms.UserControl, IPropertiesPage
	{
		// ------------------------------------------------------------------------------
		// Construction

		/// <summary>
		/// Constructor
		/// </summary>
		public DetailProperties()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
		}


		// ------------------------------------------------------------------------------
		// IPropertiesPage implementation

		/// <summary>
		/// Init Properties
		/// </summary>
		public void InitProperties()
		{
			this.chkSubpatch.Checked = PropertiesService.Instance.Subpatch;
			this.chkWeights.Checked	= PropertiesService.Instance.ApplyWeights;
			this.cmbSubpatch.SelectedIndex = PropertiesService.Instance.PatchLevel - 1;
			
			this.chkSubpatch.CheckedChanged += new System.EventHandler(this.OnObjectRefreshRequired);
			this.chkWeights.CheckedChanged += new System.EventHandler(this.OnObjectRefreshRequired);
			this.cmbSubpatch.SelectedIndexChanged += new System.EventHandler(this.OnObjectRefreshRequired);
		}

		/// <summary>
		/// Save Properties
		/// </summary>
		public void SaveProperties()
		{
			PropertiesService.Instance.Subpatch	= this.chkSubpatch.Checked;
			PropertiesService.Instance.ApplyWeights = this.chkWeights.Checked;
			PropertiesService.Instance.PatchLevel = this.cmbSubpatch.SelectedIndex + 1;
		}

		/// <summary>
		/// Get the text title for the page
		/// </summary>
		/// <returns>Title text</returns>
		public string GetTitle()
		{
			return "Detail";
		}

		/// <summary>
		/// Container form
		/// </summary>
		/// <param name="container"></param>
		public void SetContainer(PropertiesContainerForm container)
		{
			m_container = container;
		}


		// ------------------------------------------------------------------------------
		// Private methods

		/// <summary>
		/// User has changed a value causing the parent object to need refreshing
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void OnObjectRefreshRequired(object sender, System.EventArgs e)
		{
			m_container.RefreshLoadedItem = true;
		}


		// ------------------------------------------------------------------------------
		// Designer code

		#region Component Designer generated code
		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.lblSubpatchLevel = new System.Windows.Forms.Label();
			this.chkWeights = new System.Windows.Forms.CheckBox();
			this.chkSubpatch = new System.Windows.Forms.CheckBox();
			this.cmbSubpatch = new System.Windows.Forms.ComboBox();
			this.label2 = new System.Windows.Forms.Label();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.lblSubpatchLevel);
			this.groupBox1.Controls.Add(this.chkWeights);
			this.groupBox1.Controls.Add(this.chkSubpatch);
			this.groupBox1.Controls.Add(this.cmbSubpatch);
			this.groupBox1.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBox1.Location = new System.Drawing.Point(8, 8);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(320, 112);
			this.groupBox1.TabIndex = 5;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "Sub-patching";
			// 
			// lblSubpatchLevel
			// 
			this.lblSubpatchLevel.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.lblSubpatchLevel.Location = new System.Drawing.Point(16, 84);
			this.lblSubpatchLevel.Name = "lblSubpatchLevel";
			this.lblSubpatchLevel.Size = new System.Drawing.Size(80, 23);
			this.lblSubpatchLevel.TabIndex = 3;
			this.lblSubpatchLevel.Text = "Sub-patch level:";
			// 
			// chkWeights
			// 
			this.chkWeights.Enabled = false;
			this.chkWeights.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.chkWeights.Location = new System.Drawing.Point(16, 48);
			this.chkWeights.Name = "chkWeights";
			this.chkWeights.Size = new System.Drawing.Size(248, 24);
			this.chkWeights.TabIndex = 1;
			this.chkWeights.Text = "Apply weight maps";
			// 
			// chkSubpatch
			// 
			this.chkSubpatch.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.chkSubpatch.Location = new System.Drawing.Point(16, 24);
			this.chkSubpatch.Name = "chkSubpatch";
			this.chkSubpatch.Size = new System.Drawing.Size(248, 24);
			this.chkSubpatch.TabIndex = 0;
			this.chkSubpatch.Text = "Apply sub-patching to patch polygons";
			// 
			// cmbSubpatch
			// 
			this.cmbSubpatch.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.cmbSubpatch.Items.AddRange(new object[] {
																			"Low",
																			"Medium",
																			"High"});
			this.cmbSubpatch.Location = new System.Drawing.Point(104, 80);
			this.cmbSubpatch.Name = "cmbSubpatch";
			this.cmbSubpatch.Size = new System.Drawing.Size(112, 21);
			this.cmbSubpatch.TabIndex = 2;
			// 
			// label2
			// 
			this.label2.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.label2.Location = new System.Drawing.Point(16, 232);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(304, 32);
			this.label2.TabIndex = 6;
			this.label2.Text = "Note: Setting sub-patch level to High is not recommended for slow machines or mac" +
				"hines with low memory.";
			// 
			// DetailProperties
			// 
			this.Controls.Add(this.label2);
			this.Controls.Add(this.groupBox1);
			this.Name = "DetailProperties";
			this.Size = new System.Drawing.Size(336, 272);
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion
	
	
		// ------------------------------------------------------------------------------
		// Private data

		/// <summary>
		/// Container form
		/// </summary>
		private PropertiesContainerForm m_container = null;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.ComboBox cmbSubpatch;
		private System.Windows.Forms.CheckBox chkSubpatch;
		private System.Windows.Forms.Label lblSubpatchLevel;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.CheckBox chkWeights;

		/// <summary>
		/// Controls
		/// </summary>
		private System.ComponentModel.Container components = null;
	}
}
