namespace K3D.Properties
{
	using System;
	using System.Collections;
	using System.ComponentModel;
	using System.Drawing;
	using System.Data;
	using System.Windows.Forms;

	using K3D.Services;


	/// <summary>
	/// General Properties.
	/// </summary>
	public sealed class GeneralProperties : System.Windows.Forms.UserControl, IPropertiesPage
	{
		// ------------------------------------------------------------------------------
		// Construction

		/// <summary>
		/// Constructor
		/// </summary>
		public GeneralProperties()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
		}


		// ------------------------------------------------------------------------------
		// IPropertiesPage implementation

		/// <summary>
		/// Init Properties
		/// </summary>
		public void InitProperties()
		{
			this.chkScale.Checked = PropertiesService.Instance.AutoScale;
			this.chkCenter.Checked = PropertiesService.Instance.AutoCentre;
			this.chkReset.Checked = PropertiesService.Instance.ResetObject;
         this.numericRotate.Value = new Decimal(PropertiesService.Instance.KeyRotation);
         this.numericScale.Value = new Decimal(PropertiesService.Instance.KeyScaling);
         this.folderBrowserDialog.SelectedPath = PropertiesService.Instance.ContentFolder;
         this.txtContentFolder.Text = this.folderBrowserDialog.SelectedPath;
		}

		/// <summary>
		/// Save Properties
		/// </summary>
		public void SaveProperties()
		{
			PropertiesService.Instance.AutoScale = this.chkScale.Checked;
			PropertiesService.Instance.AutoCentre = this.chkCenter.Checked;
			PropertiesService.Instance.ResetObject = this.chkReset.Checked;
         PropertiesService.Instance.KeyRotation = Decimal.ToInt32(this.numericRotate.Value);
         PropertiesService.Instance.KeyScaling = (float)Decimal.ToDouble(this.numericScale.Value);
         PropertiesService.Instance.ContentFolder = this.folderBrowserDialog.SelectedPath;
		}

		/// <summary>
		/// Get the text title for the page
		/// </summary>
		/// <returns>Title text</returns>
		public string GetTitle()
		{
			return "General";
		}

		/// <summary>
		/// Container form
		/// </summary>
		/// <param name="container"></param>
		public void SetContainer(PropertiesContainerForm container)
		{
			m_container = container;
		}

      /// <summary>
      /// Content folder browse button pressed
      /// </summary>
      /// <param name="sender"></param>
      /// <param name="e"></param>
      private void OnBrowse(object sender, System.EventArgs e)
      {
         if (this.folderBrowserDialog.ShowDialog() == DialogResult.OK)
         {
            this.txtContentFolder.Text = this.folderBrowserDialog.SelectedPath;
         }
      }


		// ------------------------------------------------------------------------------
		// Designer code

		#region Component Designer generated code
		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
         this.groupBox1 = new System.Windows.Forms.GroupBox();
         this.chkReset = new System.Windows.Forms.CheckBox();
         this.chkScale = new System.Windows.Forms.CheckBox();
         this.chkCenter = new System.Windows.Forms.CheckBox();
         this.groupBox2 = new System.Windows.Forms.GroupBox();
         this.label3 = new System.Windows.Forms.Label();
         this.label2 = new System.Windows.Forms.Label();
         this.numericRotate = new System.Windows.Forms.NumericUpDown();
         this.numericScale = new System.Windows.Forms.NumericUpDown();
         this.label4 = new System.Windows.Forms.Label();
         this.label1 = new System.Windows.Forms.Label();
         this.groupBox3 = new System.Windows.Forms.GroupBox();
         this.btnSelectPath = new System.Windows.Forms.Button();
         this.txtContentFolder = new System.Windows.Forms.TextBox();
         this.folderBrowserDialog = new System.Windows.Forms.FolderBrowserDialog();
         this.groupBox1.SuspendLayout();
         this.groupBox2.SuspendLayout();
         ((System.ComponentModel.ISupportInitialize)(this.numericRotate)).BeginInit();
         ((System.ComponentModel.ISupportInitialize)(this.numericScale)).BeginInit();
         this.groupBox3.SuspendLayout();
         this.SuspendLayout();
         // 
         // groupBox1
         // 
         this.groupBox1.Controls.Add(this.chkReset);
         this.groupBox1.Controls.Add(this.chkScale);
         this.groupBox1.Controls.Add(this.chkCenter);
         this.groupBox1.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.groupBox1.Location = new System.Drawing.Point(8, 8);
         this.groupBox1.Name = "groupBox1";
         this.groupBox1.Size = new System.Drawing.Size(320, 96);
         this.groupBox1.TabIndex = 2;
         this.groupBox1.TabStop = false;
         this.groupBox1.Text = "Automatic Scaling and Centering";
         // 
         // chkReset
         // 
         this.chkReset.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.chkReset.Location = new System.Drawing.Point(16, 64);
         this.chkReset.Name = "chkReset";
         this.chkReset.Size = new System.Drawing.Size(288, 24);
         this.chkReset.TabIndex = 2;
         this.chkReset.Text = "Reset object rotation and position after opening file";
         // 
         // chkScale
         // 
         this.chkScale.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.chkScale.Location = new System.Drawing.Point(16, 16);
         this.chkScale.Name = "chkScale";
         this.chkScale.Size = new System.Drawing.Size(248, 24);
         this.chkScale.TabIndex = 0;
         this.chkScale.Text = "Automatically scale object to fit window";
         // 
         // chkCenter
         // 
         this.chkCenter.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.chkCenter.Location = new System.Drawing.Point(16, 40);
         this.chkCenter.Name = "chkCenter";
         this.chkCenter.Size = new System.Drawing.Size(248, 24);
         this.chkCenter.TabIndex = 1;
         this.chkCenter.Text = "Automatically center object to origin";
         // 
         // groupBox2
         // 
         this.groupBox2.Controls.Add(this.label3);
         this.groupBox2.Controls.Add(this.label2);
         this.groupBox2.Controls.Add(this.numericRotate);
         this.groupBox2.Controls.Add(this.numericScale);
         this.groupBox2.Controls.Add(this.label4);
         this.groupBox2.Controls.Add(this.label1);
         this.groupBox2.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.groupBox2.Location = new System.Drawing.Point(8, 112);
         this.groupBox2.Name = "groupBox2";
         this.groupBox2.Size = new System.Drawing.Size(321, 72);
         this.groupBox2.TabIndex = 3;
         this.groupBox2.TabStop = false;
         this.groupBox2.Text = "Keyboard Controlled Object Rotation and Scaling";
         // 
         // label3
         // 
         this.label3.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.label3.Location = new System.Drawing.Point(128, 44);
         this.label3.Name = "label3";
         this.label3.Size = new System.Drawing.Size(182, 23);
         this.label3.TabIndex = 4;
         this.label3.Text = "multiplier using the \"<\" and \">\" keys";
         this.label3.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
         this.label3.UseMnemonic = false;
         // 
         // label2
         // 
         this.label2.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.label2.Location = new System.Drawing.Point(128, 20);
         this.label2.Name = "label2";
         this.label2.Size = new System.Drawing.Size(168, 23);
         this.label2.TabIndex = 2;
         this.label2.Text = "degress using the arrow keys";
         this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
         this.label2.UseMnemonic = false;
         // 
         // numericRotate
         // 
         this.numericRotate.Location = new System.Drawing.Point(72, 16);
         this.numericRotate.Maximum = new System.Decimal(new int[] {
                                                                      90,
                                                                      0,
                                                                      0,
                                                                      0});
         this.numericRotate.Name = "numericRotate";
         this.numericRotate.Size = new System.Drawing.Size(48, 20);
         this.numericRotate.TabIndex = 1;
         // 
         // numericScale
         // 
         this.numericScale.DecimalPlaces = 2;
         this.numericScale.Increment = new System.Decimal(new int[] {
                                                                       1,
                                                                       0,
                                                                       0,
                                                                       131072});
         this.numericScale.Location = new System.Drawing.Point(72, 40);
         this.numericScale.Maximum = new System.Decimal(new int[] {
                                                                     2,
                                                                     0,
                                                                     0,
                                                                     0});
         this.numericScale.Minimum = new System.Decimal(new int[] {
                                                                     1,
                                                                     0,
                                                                     0,
                                                                     0});
         this.numericScale.Name = "numericScale";
         this.numericScale.Size = new System.Drawing.Size(48, 20);
         this.numericScale.TabIndex = 2;
         this.numericScale.Value = new System.Decimal(new int[] {
                                                                   1,
                                                                   0,
                                                                   0,
                                                                   0});
         // 
         // label4
         // 
         this.label4.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.label4.Location = new System.Drawing.Point(16, 44);
         this.label4.Name = "label4";
         this.label4.Size = new System.Drawing.Size(64, 23);
         this.label4.TabIndex = 3;
         this.label4.Text = "Scale by";
         this.label4.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
         this.label4.UseMnemonic = false;
         // 
         // label1
         // 
         this.label1.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.label1.Location = new System.Drawing.Point(16, 20);
         this.label1.Name = "label1";
         this.label1.Size = new System.Drawing.Size(64, 23);
         this.label1.TabIndex = 0;
         this.label1.Text = "Rotate by";
         this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
         this.label1.UseMnemonic = false;
         // 
         // groupBox3
         // 
         this.groupBox3.Controls.Add(this.txtContentFolder);
         this.groupBox3.Controls.Add(this.btnSelectPath);
         this.groupBox3.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.groupBox3.Location = new System.Drawing.Point(8, 192);
         this.groupBox3.Name = "groupBox3";
         this.groupBox3.Size = new System.Drawing.Size(320, 56);
         this.groupBox3.TabIndex = 4;
         this.groupBox3.TabStop = false;
         this.groupBox3.Text = "Path to Lightwave Content Folder";
         // 
         // btnSelectPath
         // 
         this.btnSelectPath.FlatStyle = System.Windows.Forms.FlatStyle.System;
         this.btnSelectPath.Location = new System.Drawing.Point(16, 22);
         this.btnSelectPath.Name = "btnSelectPath";
         this.btnSelectPath.Size = new System.Drawing.Size(24, 23);
         this.btnSelectPath.TabIndex = 0;
         this.btnSelectPath.Text = "...";
         this.btnSelectPath.Click += new System.EventHandler(this.OnBrowse);
         // 
         // txtContentFolder
         // 
         this.txtContentFolder.Location = new System.Drawing.Point(48, 24);
         this.txtContentFolder.MaxLength = 1024;
         this.txtContentFolder.Name = "txtContentFolder";
         this.txtContentFolder.ReadOnly = true;
         this.txtContentFolder.Size = new System.Drawing.Size(256, 20);
         this.txtContentFolder.TabIndex = 1;
         this.txtContentFolder.Text = "";
         // 
         // folderBrowserDialog
         // 
         this.folderBrowserDialog.Description = "Select Lightwave Content Folder";
         this.folderBrowserDialog.ShowNewFolderButton = false;
         // 
         // GeneralProperties
         // 
         this.Controls.Add(this.groupBox3);
         this.Controls.Add(this.groupBox1);
         this.Controls.Add(this.groupBox2);
         this.Name = "GeneralProperties";
         this.Size = new System.Drawing.Size(336, 256);
         this.groupBox1.ResumeLayout(false);
         this.groupBox2.ResumeLayout(false);
         ((System.ComponentModel.ISupportInitialize)(this.numericRotate)).EndInit();
         ((System.ComponentModel.ISupportInitialize)(this.numericScale)).EndInit();
         this.groupBox3.ResumeLayout(false);
         this.ResumeLayout(false);

      }
		#endregion
	
	
		// ------------------------------------------------------------------------------
		// Private data

		/// <summary>
		/// Container form
		/// </summary>
		private PropertiesContainerForm m_container = null;

		/// <summary>
		/// Controls
		/// </summary>
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.CheckBox chkScale;
		private System.Windows.Forms.CheckBox chkCenter;
		private System.Windows.Forms.GroupBox groupBox2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.NumericUpDown numericRotate;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.NumericUpDown numericScale;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.CheckBox chkReset;
      private System.Windows.Forms.GroupBox groupBox3;
      private System.Windows.Forms.Button btnSelectPath;
      private System.Windows.Forms.FolderBrowserDialog folderBrowserDialog;
      private System.Windows.Forms.TextBox txtContentFolder;
		private System.ComponentModel.Container components = null;
	}
}
