namespace K3D.Properties
{
	using System;
	using System.Collections;
	using System.ComponentModel;
	using System.Drawing;
	using System.Data;
	using System.Windows.Forms;

	using K3D.Services;


	/// <summary>
	/// Polygon Properties.
	/// </summary>
	public sealed class PolygonProperties : System.Windows.Forms.UserControl, IPropertiesPage
	{
		// ------------------------------------------------------------------------------
		// Construction

		/// <summary>
		/// Constructor
		/// </summary>
		public PolygonProperties()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
		}


		// ------------------------------------------------------------------------------
		// IPropertiesPage implementation

		/// <summary>
		/// Init Properties
		/// </summary>
		public void InitProperties()
		{
			this.chkTess.Checked		= PropertiesService.Instance.Tesselate;
			this.chkPoints.Checked	= PropertiesService.Instance.ShowPoints;
			this.chkLines.Checked	= PropertiesService.Instance.ShowLines;
			this.chkTris.Checked		= PropertiesService.Instance.ShowTris;
			this.chkQuads.Checked	= PropertiesService.Instance.ShowQuads;
			this.chkPolys.Checked   = PropertiesService.Instance.ShowPolys;
			
			this.chkTess.CheckedChanged += new System.EventHandler(this.OnObjectRefreshRequired);
			this.chkPoints.CheckedChanged += new System.EventHandler(this.OnObjectRefreshRequired);
			this.chkPolys.CheckedChanged += new System.EventHandler(this.OnObjectRefreshRequired);
			this.chkQuads.CheckedChanged += new System.EventHandler(this.OnObjectRefreshRequired);
			this.chkTris.CheckedChanged += new System.EventHandler(this.OnObjectRefreshRequired);
			this.chkLines.CheckedChanged += new System.EventHandler(this.OnObjectRefreshRequired);
		}

		/// <summary>
		/// Save Properties
		/// </summary>
		public void SaveProperties()
		{
			PropertiesService.Instance.Tesselate	= this.chkTess.Checked;
			PropertiesService.Instance.ShowPoints	= this.chkPoints.Checked;
			PropertiesService.Instance.ShowLines	= this.chkLines.Checked;
			PropertiesService.Instance.ShowTris		= this.chkTris.Checked;
			PropertiesService.Instance.ShowQuads	= this.chkQuads.Checked;
			PropertiesService.Instance.ShowPolys	= this.chkPolys.Checked;
		}

		/// <summary>
		/// Get the text title for the page
		/// </summary>
		/// <returns>Title text</returns>
		public string GetTitle()
		{
			return "Polygon";
		}

		/// <summary>
		/// Container form
		/// </summary>
		/// <param name="container"></param>
		public void SetContainer(PropertiesContainerForm container)
		{
			m_container = container;
		}


		// ------------------------------------------------------------------------------
		// Private methods

		/// <summary>
		/// User has changed a value causing the parent object to need refreshing
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void OnObjectRefreshRequired(object sender, System.EventArgs e)
		{
			m_container.RefreshLoadedItem = true;
		}



		// ------------------------------------------------------------------------------
		// Designer code

		#region Component Designer generated code
		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.chkTess = new System.Windows.Forms.CheckBox();
			this.groupBox2 = new System.Windows.Forms.GroupBox();
			this.chkPolys = new System.Windows.Forms.CheckBox();
			this.chkQuads = new System.Windows.Forms.CheckBox();
			this.chkTris = new System.Windows.Forms.CheckBox();
			this.chkLines = new System.Windows.Forms.CheckBox();
			this.label1 = new System.Windows.Forms.Label();
			this.chkPoints = new System.Windows.Forms.CheckBox();
			this.label2 = new System.Windows.Forms.Label();
			this.groupBox1.SuspendLayout();
			this.groupBox2.SuspendLayout();
			this.SuspendLayout();
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.chkTess);
			this.groupBox1.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBox1.Location = new System.Drawing.Point(8, 8);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(320, 64);
			this.groupBox1.TabIndex = 0;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "Tesselation";
			// 
			// chkTess
			// 
			this.chkTess.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.chkTess.Location = new System.Drawing.Point(16, 24);
			this.chkTess.Name = "chkTess";
			this.chkTess.Size = new System.Drawing.Size(296, 24);
			this.chkTess.TabIndex = 0;
			this.chkTess.Text = "Convert complex polygons to triangles (tesselate)";
			// 
			// groupBox2
			// 
			this.groupBox2.Controls.Add(this.chkPolys);
			this.groupBox2.Controls.Add(this.chkQuads);
			this.groupBox2.Controls.Add(this.chkTris);
			this.groupBox2.Controls.Add(this.chkLines);
			this.groupBox2.Controls.Add(this.label1);
			this.groupBox2.Controls.Add(this.chkPoints);
			this.groupBox2.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBox2.Location = new System.Drawing.Point(8, 80);
			this.groupBox2.Name = "groupBox2";
			this.groupBox2.Size = new System.Drawing.Size(320, 144);
			this.groupBox2.TabIndex = 1;
			this.groupBox2.TabStop = false;
			this.groupBox2.Text = "Polygon Types";
			// 
			// chkPolys
			// 
			this.chkPolys.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.chkPolys.Location = new System.Drawing.Point(168, 80);
			this.chkPolys.Name = "chkPolys";
			this.chkPolys.Size = new System.Drawing.Size(120, 24);
			this.chkPolys.TabIndex = 4;
			this.chkPolys.Text = "Polygons (>4 points)";
			// 
			// chkQuads
			// 
			this.chkQuads.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.chkQuads.Location = new System.Drawing.Point(168, 48);
			this.chkQuads.Name = "chkQuads";
			this.chkQuads.Size = new System.Drawing.Size(120, 24);
			this.chkQuads.TabIndex = 3;
			this.chkQuads.Text = "Quads (4 points)";
			// 
			// chkTris
			// 
			this.chkTris.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.chkTris.Location = new System.Drawing.Point(16, 112);
			this.chkTris.Name = "chkTris";
			this.chkTris.Size = new System.Drawing.Size(120, 24);
			this.chkTris.TabIndex = 2;
			this.chkTris.Text = "Triangles (3 points)";
			// 
			// chkLines
			// 
			this.chkLines.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.chkLines.Location = new System.Drawing.Point(16, 80);
			this.chkLines.Name = "chkLines";
			this.chkLines.Size = new System.Drawing.Size(120, 24);
			this.chkLines.TabIndex = 1;
			this.chkLines.Text = "Lines (2 points)";
			// 
			// label1
			// 
			this.label1.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.label1.Location = new System.Drawing.Point(16, 24);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(184, 23);
			this.label1.TabIndex = 1;
			this.label1.Text = "Display the following polygon types:";
			// 
			// chkPoints
			// 
			this.chkPoints.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.chkPoints.Location = new System.Drawing.Point(16, 48);
			this.chkPoints.Name = "chkPoints";
			this.chkPoints.Size = new System.Drawing.Size(120, 24);
			this.chkPoints.TabIndex = 0;
			this.chkPoints.Text = "Single Points";
			// 
			// label2
			// 
			this.label2.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.label2.Location = new System.Drawing.Point(16, 232);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(304, 32);
			this.label2.TabIndex = 4;
			this.label2.Text = "Note: Changing these properties with cause the current object to be reloaded and " +
				"rendered with the new settings.";
			// 
			// PolygonProperties
			// 
			this.Controls.Add(this.label2);
			this.Controls.Add(this.groupBox2);
			this.Controls.Add(this.groupBox1);
			this.Name = "PolygonProperties";
			this.Size = new System.Drawing.Size(336, 272);
			this.groupBox1.ResumeLayout(false);
			this.groupBox2.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion
	
	
		// ------------------------------------------------------------------------------
		// Private data

		/// <summary>
		/// Container form
		/// </summary>
		private PropertiesContainerForm m_container = null;

		/// <summary>
		/// Controls
		/// </summary>
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.CheckBox chkTess;
		private System.Windows.Forms.GroupBox groupBox2;
		private System.Windows.Forms.CheckBox chkPoints;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.CheckBox chkLines;
		private System.Windows.Forms.CheckBox chkTris;
		private System.Windows.Forms.CheckBox chkPolys;
		private System.Windows.Forms.CheckBox chkQuads;
		private System.Windows.Forms.Label label2;
		private System.ComponentModel.Container components = null;
	}
}
