namespace K3D.Properties
{
	using System;
	using System.Drawing;
	using System.Collections;
	using System.ComponentModel;
	using System.Windows.Forms;


	/// <summary>
	/// Properties Container Form.
	/// </summary>
	public sealed class PropertiesContainerForm : System.Windows.Forms.Form
	{
		// ------------------------------------------------------------------------------
		// Construction

		/// <summary>
		/// Constructor
		/// </summary>
		public PropertiesContainerForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
		}


		// ------------------------------------------------------------------------------
		// Designer code

		#region Windows Form Designer generated code
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(PropertiesContainerForm));
			this.buttonBox = new System.Windows.Forms.GroupBox();
			this.btnCancel = new System.Windows.Forms.Button();
			this.btnOK = new System.Windows.Forms.Button();
			this.tabControl = new System.Windows.Forms.TabControl();
			this.buttonBox.SuspendLayout();
			this.SuspendLayout();
			// 
			// buttonBox
			// 
			this.buttonBox.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.buttonBox.Controls.Add(this.btnCancel);
			this.buttonBox.Controls.Add(this.btnOK);
			this.buttonBox.Location = new System.Drawing.Point(-2, 288);
			this.buttonBox.Name = "buttonBox";
			this.buttonBox.Size = new System.Drawing.Size(354, 72);
			this.buttonBox.TabIndex = 99;
			this.buttonBox.TabStop = false;
			// 
			// btnCancel
			// 
			this.btnCancel.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.btnCancel.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnCancel.Location = new System.Drawing.Point(264, 14);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.TabIndex = 1;
			this.btnCancel.Text = "&Cancel";
			// 
			// btnOK
			// 
			this.btnOK.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.btnOK.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.btnOK.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnOK.Location = new System.Drawing.Point(176, 14);
			this.btnOK.Name = "btnOK";
			this.btnOK.TabIndex = 0;
			this.btnOK.Text = "&OK";
			this.btnOK.Click += new System.EventHandler(this.OnOK);
			// 
			// tabControl
			// 
			this.tabControl.Dock = System.Windows.Forms.DockStyle.Top;
			this.tabControl.Location = new System.Drawing.Point(0, 0);
			this.tabControl.Name = "tabControl";
			this.tabControl.SelectedIndex = 0;
			this.tabControl.Size = new System.Drawing.Size(346, 296);
			this.tabControl.TabIndex = 0;
			// 
			// PropertiesContainerForm
			// 
			this.AcceptButton = this.btnOK;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.btnCancel;
			this.ClientSize = new System.Drawing.Size(346, 333);
			this.Controls.Add(this.tabControl);
			this.Controls.Add(this.buttonBox);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "PropertiesContainerForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "Preferences";
			this.buttonBox.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion
	
	
		// ------------------------------------------------------------------------------
		// Public API

		/// <summary>
		/// Add a page to be shown in the tabbed dialog
		/// </summary>
		/// <param name="page"></param>
		public void AddPropertiesPage(IPropertiesPage page)
		{
			UserControl ctrlPage = page as UserControl;
			if (ctrlPage == null)
			{
				throw new Exception("IPropertiesPage must be a UserControl!");
			}
			
			page.InitProperties();
			page.SetContainer(this);

			TabPage tabPage = new TabPage(page.GetTitle());
			ctrlPage.Dock = DockStyle.Fill;
			tabPage.Controls.Add(ctrlPage);
			this.tabControl.TabPages.Add(tabPage);
			
			m_pages.Add(page);
		}

		/// <summary>
		/// Whether we should refresh the loaded item upon return from the dialog
		/// </summary>
		public bool RefreshLoadedItem
		{
			get
			{
				return m_refresh;
			}
			set
			{
				m_refresh = value;
			}
		}


		// ------------------------------------------------------------------------------
		// Private methods

		/// <summary>
		/// OK button pressed
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void OnOK(object sender, System.EventArgs e)
		{
			// persist the properties on each prop page
			foreach (IPropertiesPage page in m_pages)
			{
				page.SaveProperties();
			}
			this.Close();
		}


		// ------------------------------------------------------------------------------
		// Private data

		/// <summary>
		/// The pages as IPropertiesPage objects
		/// </summary>
		private ArrayList m_pages = new ArrayList();

		/// <summary>
		/// Whether we should refresh the loaded item upon return from the dialog
		/// </summary>
		private bool m_refresh = false;

		/// <summary>
		/// Controls
		/// </summary>
		private System.Windows.Forms.GroupBox buttonBox;
		private System.Windows.Forms.Button btnOK;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.TabControl tabControl;
		private System.ComponentModel.Container components = null;
	}
}
