namespace K3D.Services
{
	using System;
   using System.Drawing;


	/// <summary>
	/// Properties Service.
	/// </summary>
	public sealed class PropertiesService
	{
		// --------------------------------------------------------------------------------
		// Construction

		/// <summary>
		/// Private constructor
		/// </summary>
		private PropertiesService()
		{
		}
		
		/// <summary>
		/// Static instance
		/// </summary>
		public static PropertiesService Instance
		{
			get
			{
				return s_service;
			}
		}


		// --------------------------------------------------------------------------------
		// Public API

		public bool AutoScale
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_AUTOSCALE, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_AUTOSCALE, value);
			}
		}

		public bool AutoCentre
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_AUTOCENTRE, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_AUTOCENTRE, value);
			}
		}

      public int KeyRotation
      {
         get
         {
            return RegistryService.Instance.GetInteger(REG_KEY, PROP_KEYROTATION, 5);
         }
         set
         {
            RegistryService.Instance.PutInteger(REG_KEY, PROP_KEYROTATION, value);
         }
      }

      public float KeyScaling
      {
         get
         {
            int scale = RegistryService.Instance.GetInteger(REG_KEY, PROP_KEYSCALE, 1100);
            return ((float)scale)/1000.0f;
         }
         set
         {
            int scale = (int)(value * 1000.0f);
            RegistryService.Instance.PutInteger(REG_KEY, PROP_KEYSCALE, scale);
         }
      }

		public bool Tesselate
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_TESSELATE, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_TESSELATE, value);
			}
		}

		public bool ShowPoints
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_SHOWPOINTS, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_SHOWPOINTS, value);
			}
		}

		public bool ShowLines
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_SHOWLINES, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_SHOWLINES, value);
			}
		}

		public bool ShowTris
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_SHOWTRIS, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_SHOWTRIS, value);
			}
		}

		public bool ShowQuads
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_SHOWQUADS, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_SHOWQUADS, value);
			}
		}

		public bool ShowPolys
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_SHOWPOLYS, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_SHOWPOLYS, value);
			}
		}

		public int DisplayMode
		{
			get
			{
				return RegistryService.Instance.GetInteger(REG_KEY, PROP_DISPLAYMODE, 4);
			}
			set
			{
				RegistryService.Instance.PutInteger(REG_KEY, PROP_DISPLAYMODE, value);
			}
		}

      public bool Transparency
      {
         get
         {
            return RegistryService.Instance.GetBoolean(REG_KEY, PROP_TRANSPARENCY, true);
         }
         set
         {
            RegistryService.Instance.PutBoolean(REG_KEY, PROP_TRANSPARENCY, value);
         }
      }

      public bool BackFaces
      {
         get
         {
            return RegistryService.Instance.GetBoolean(REG_KEY, PROP_BACKFACES, false);
         }
         set
         {
            RegistryService.Instance.PutBoolean(REG_KEY, PROP_BACKFACES, value);
         }
      }

		public bool ResetObject
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_RESETGEOM, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_RESETGEOM, value);
			}
		}

      public Color BackgroundColour
      {
         get
         {
            int[] colInts = RegistryService.Instance.GetIntegerArray(REG_KEY, PROP_BACKGROUND);
            if (colInts != null && colInts.Length == 3)
            {
               return Color.FromArgb(colInts[0], colInts[1], colInts[2]);
            }
            else
            {
               // default is middle grey
               return Color.FromArgb(128, 128, 128);
            }
         }
         set
         {
            int[] colInts = {value.R, value.G, value.B};
            RegistryService.Instance.PutIntegerArray(REG_KEY, PROP_BACKGROUND, colInts);
         }
      }

      public string ContentFolder
      {
         get
         {
            return RegistryService.Instance.GetString(REG_KEY, PROP_CONTENTFOLDER, string.Empty);
         }
         set
         {
            RegistryService.Instance.PutString(REG_KEY, PROP_CONTENTFOLDER, value);
         }
      }

		public bool Subpatch
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_SUBPATCH, true);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_SUBPATCH, value);
			}
		}

		public bool ApplyWeights
		{
			get
			{
				return RegistryService.Instance.GetBoolean(REG_KEY, PROP_WEIGHTS, false);
			}
			set
			{
				RegistryService.Instance.PutBoolean(REG_KEY, PROP_WEIGHTS, value);
			}
		}

		public int PatchLevel
		{
			get
			{
				return RegistryService.Instance.GetInteger(REG_KEY, PROP_PATCHLEVEL, 1);
			}
			set
			{
				RegistryService.Instance.PutInteger(REG_KEY, PROP_PATCHLEVEL, value);
			}
		}


		// --------------------------------------------------------------------------------
		// Private data

		private const string REG_KEY			      = "Properties";

		private const string PROP_AUTOSCALE		   = "AutoScale";
		private const string PROP_AUTOCENTRE	   = "AutoCentre";
      private const string PROP_KEYROTATION     = "KeyRotation";
      private const string PROP_KEYSCALE        = "KeyScale";
		private const string PROP_TESSELATE       = "Tesselate";
		private const string PROP_SHOWPOINTS      = "ShowPoints";
		private const string PROP_SHOWLINES		   = "ShowLines";
		private const string PROP_SHOWTRIS		   = "ShowTris";
		private const string PROP_SHOWQUADS		   = "ShowQuads";
		private const string PROP_SHOWPOLYS		   = "ShowPolys";
		private const string PROP_DISPLAYMODE     = "DisplayMode";
      private const string PROP_TRANSPARENCY    = "Transparency";
      private const string PROP_BACKGROUND      = "Background";
      private const string PROP_BACKFACES       = "BackFaces";
		private const string PROP_RESETGEOM		   = "ResetGeom";
      private const string PROP_CONTENTFOLDER   = "ContentFolder";
		private const string PROP_SUBPATCH			= "Subpatch";
		private const string PROP_WEIGHTS			= "Weights";
		private const string PROP_PATCHLEVEL		= "PatchLevel";

		private static PropertiesService s_service = new PropertiesService();
	}
}
