namespace K3D.ThreeD.Lightwave
{
	using System;
	using System.Collections;
	
	using K3D.Geometry;


	/// <summary>
	/// PointInfo class.
	/// Holds reference to an associated face point and associated edges points.
	/// </summary>
	public sealed class PointInfo
	{
		public void AddFacePointRef(int index)
		{
			if (FaceRefCount == m_facePointRefs.Length)
			{
				// resize arrays by hand to fit and copy to new arrays
				int[] temp = new int[FaceRefCount << 1];
				Array.Copy(m_facePointRefs, temp, FaceRefCount);
				m_facePointRefs = temp;
			}
			m_facePointRefs[FaceRefCount++] = index;
		}

		public void AddEdgePoint(Point edgePoint)
		{
			if (EdgePointCount == m_edgePoints.Length)
			{
				// resize arrays by hand to fit and copy to new arrays
				Point[] temp = new Point[EdgePointCount << 1];
				Array.Copy(m_edgePoints, temp, EdgePointCount);
				m_edgePoints = temp;
			}
			m_edgePoints[EdgePointCount++] = edgePoint;
		}

		public Point FacePointAverage(ArrayList points)
		{
			// perform a single div now and mults instead later
			float multipler = 1.0f / (float)FaceRefCount;
			
			// average all the face points for this vertex
			float x, y, z;
			x = y = z = 0.0f;
			Point p;
			for (int i=0; i<FaceRefCount; i++)
			{
				p = (Point)points[ m_facePointRefs[i] ];
				x += p.X;
				y += p.Y;
				z += p.Z;
			}
			x *= multipler;
			y *= multipler;
			z *= multipler;
			
			return new Point(x, y, z);
		}

		public Point EdgePointAverage2R(ArrayList points)
		{
			// perform a single div now and mults instead later
			// note that we multiply by 2 to give 2R
			float avmult = (1.0f / (float)EdgePointCount) * 2.0f;
			
			// average all the edge mid points for this vertex
			float x, y, z;
			x = y = z = 0.0f;
			Point p;
			for (int i=0; i<EdgePointCount; i++)
			{
				p = m_edgePoints[i];
				x += p.X;
				y += p.Y;
				z += p.Z;
			}
			x *= avmult;
			y *= avmult;
			z *= avmult;
			
			return new Point(x, y, z);
		}
		
		public int FaceRefCount   = 0;
		public int EdgePointCount = 0;

		public int NewVertexPointIndex = -1;
		
		private int[] m_facePointRefs = new int[4];
		private Point[] m_edgePoints = new Point[4];
	}
}
